# English introduction
TruePigLatin —— possibly the fastest and most accurate (doge) Pig Latin translator, making it easy for you to translate!

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 中文介绍
TruePigLatin ——可能是史上运行速度最快、最准（doge）的Pig Latin翻译器，让你轻松翻译！

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 用法
> `import truepiglatin [as tpl]`
> 
> `pl = tpl[truepiglatin].translate("这是个示例。This is a EXAMPLE.")`
> 
> `print(pl)`
> 
> 则显示”这是个示例。Isthay isyay a EXAMPLEYAY.“
> 
> P.S.:可输入dash=关键字，指定Pig Latin式样（Isthay isyay a EXAMPLEYAY.风格或Is-thay is-yay a EXAMPLE-YAY.风格）。

- - - - - - - - - - - - - - - - - - - - - - - - - - - -
# bug反馈
### 如您在使用中发现任何问题，请访问作者[GitHub](https://github.com/CHUA-X/TruePigLatin/issues "作者的GitHub")留言反馈，谢谢！